.. |PythonDistRecommended| replace:: The development package (python-dev or python-devel on most Linux distributions) is recommended (see just below)
.. |PlatformCompiler| replace:: ``g++`` (Linux and Windows), ``clang`` (OS X)

.. |CompilerName| replace:: ``g++`` (Windows/Linux) or ``Clang`` (OS X)
.. include:: requirements.inc
